pub struct Connection { /* private fields */ }Expand description
A descriptive connection from a terminal to a net or node.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub const fn new(terminal: Terminal, target: ConnectionTarget) -> Self
pub const fn new(terminal: Terminal, target: ConnectionTarget) -> Self
Creates a connection from a terminal to a target.
Sourcepub const fn to_net(terminal: Terminal, net: NetId) -> Self
pub const fn to_net(terminal: Terminal, net: NetId) -> Self
Creates a terminal-to-net connection.
Sourcepub const fn to_node(terminal: Terminal, node: NodeId) -> Self
pub const fn to_node(terminal: Terminal, node: NodeId) -> Self
Creates a terminal-to-node connection.
Sourcepub const fn target(&self) -> &ConnectionTarget
pub const fn target(&self) -> &ConnectionTarget
Returns the connection target.