pub struct Terminal { /* private fields */ }Expand description
A component terminal represented as a component pin reference.
Implementations
Sourceimpl Terminal
impl Terminal
Sourcepub const fn from_pin_ref(pin_ref: PinRef) -> Self
pub const fn from_pin_ref(pin_ref: PinRef) -> Self
Creates a terminal from a pin reference.
Sourcepub const fn new(component: ReferenceDesignator, pin: PinIdentifier) -> Self
pub const fn new(component: ReferenceDesignator, pin: PinIdentifier) -> Self
Creates a terminal from a component and pin identifier.